from setuptools import setup, find_packages

setup(
    name='response-package-lfb',  # Substitua pelo nome do pacote desejado
    version='1.0.0',  # Substitua pela versão desejada
    author='Lucas Frota Barroso',
    author_email='lucasfrotabarroso14@gmail.com',
    description='Pacote que contém modelos de response',
    packages=find_packages(),
    install_requires=[]  # Liste aqui quaisquer dependências
)